@@ -1,5 +1,5 @@
 package JSON::Path::Evaluator;
-$JSON::Path::Evaluator::VERSION = '1.0.2';
+$JSON::Path::Evaluator::VERSION = '1.0.3';
 use strict;
 use warnings;
 
@@ -45,6 +45,7 @@ Readonly my %OPERATORS                => (
     $TOKEN_NOT_EQUAL           => $OPERATOR_TYPE_COMPARISON,    # !=
     $TOKEN_GREATER_EQUAL       => $OPERATOR_TYPE_COMPARISON,    # >=
     $TOKEN_LESS_EQUAL          => $OPERATOR_TYPE_COMPARISON,    # <=
+    $TOKEN_REGEX               => $OPERATOR_TYPE_COMPARISON,    # =~
 );
 
 Readonly my $ASSERT_ENABLE => $ENV{ASSERT_ENABLE};
@@ -521,7 +522,7 @@ sub _parse_psuedojs_expression {
 
     my ( $lhs, $operator, $rhs );
 
-    # The operator could be '=', '!=', '==', '===', '<=', or '>='
+    # The operator could be '=', '!=', '==', '===', '<=', '>=' or '=~'
     if ( $expression =~ /$EQUAL_SIGN/ ) {
         my $position = index( $expression, '=' );
         if ( substr( $expression, $position + 1, 1 ) eq $EQUAL_SIGN ) {    # could be '==' or '==='
@@ -532,6 +533,9 @@ sub _parse_psuedojs_expression {
                 $operator = $TOKEN_DOUBLE_EQUAL;
             }
         }
+        elsif ( substr( $expression, $position + 1, 1 ) eq $TILDE_SIGN ) {
+            $operator = $TOKEN_REGEX;
+        }
         else {
             my $preceding_char = substr( $expression, $position - 1, 1 );
             if ( $preceding_char eq $GREATER_THAN_SIGN ) {
@@ -638,6 +642,18 @@ sub _compare {
     if ( $operator eq '!=' || $operator eq '!==' ) {
         return $use_numeric ? ( $lhs != $rhs ) : $lhs ne $rhs;
     }
+
+    if ( $operator eq '=~' ) {
+        if ( $rhs =~ m@^/(.*)/([msian]*)$@ ) {
+            my $regex     = $1;
+            my $modifiers = $2;
+            return $lhs =~ qr/(?$modifiers)$regex/;
+        }
+        else {
+            warn("Regexp need to be sorrounded by //. Allowed modifiers: msian");
+            return 1;
+        }
+    }
     use warnings qw/uninitialized/;
 }
 
@@ -655,7 +671,7 @@ JSON::Path::Evaluator - A module that recursively evaluates JSONPath expressions
 
 =head1 VERSION
 
-version 1.0.2
+version 1.0.3
 
 =head1 SYNOPSIS
 
@@ -890,6 +906,12 @@ Using the JSON in L<SYNOPSIS> above and the JSONPath expression C<$..book[?(@.ca
 the filter expression C<@.category == "fiction"> will match all values having a value of "fiction" for
 the key "category".
 
+Regular expressions are supported using the C<=~> operator, for example:
+C<$..book[?(@.category =~ /Fiction/i)]>.
+This is an extension of the L<Goessner specification|http://goessner.net/articles/JsonPath/>
+introduced by L<Jayway JsonPath|https://github.com/json-path/JsonPath>. Other Jayway operators
+are not currently supported.
+
 =head2 Filtering with Perl
 
 When the script engine is set to "perl", filter
@@ -905,15 +927,11 @@ When filtering in Perl, there are some differences between the JSONPath spec and
 
 =item *
 
-JSONPath uses the token '$' to refer to the root node. As this is not valid Perl, this should be
-
-replaced with '$root' in a filter expression.
+JSONPath uses the token '$' to refer to the root node. As this is not valid Perl, this should be replaced with '$root' in a filter expression.
 
 =item *
 
-JSONPath uses the token '@' to refer to the current node. This is also not valid Perl. Use '$_'
-
-instead.
+JSONPath uses the token '@' to refer to the current node. This is also not valid Perl. Use '$_' instead.
 
 =back
 
